class Event:
    def __init__(self):
        self.handlers = set()

    def __iadd__(self, handler):
        self.handlers.add(handler)
        return self

    def __isub__(self, handler):
        try:
            self.handlers.remove(handler)
        except KeyError:
            raise ValueError("Can't unhandle the handle as it's not currently handled.")
        return self

    def __call__(self, *args, **kargs):
        for handler in self.handlers:
            handler(*args, **kargs)

    def __len__(self):
        return len(self.handlers)




import requests

from multiprocessing import Process, queues
from typing import Callable, Mapping, Union

from .event import Event


class UpdateStatus(Process):
    def __init__(
        self, handlers: Event, params: Mapping, headers: Mapping, url: str
    ) -> None:
        self.params = params
        self.headers = headers
        self.url = url
        self.session = requests.Session()
        self.handlers = handlers
        super(UpdateStatus, self).__init__()

    def run(self):
        while True:
            self.params["returnon"] = "login,logout,play,pause,error,ap"
            self.params["returnafter"] = 60
            r: Response = self.session.get(
                url=self.url, params=self.params, headers=self.headers
            )
            j = r.json()
            self.handlers(j)
